@@ -1,7 +1,6 @@
-use {
-    crate::state::*,
-    anchor_lang::prelude::*,
-};
+use crate::state::*;
+
+use anchor_lang::prelude::*;
 
 #[derive(Accounts)]
 #[instruction(amount: u64)]
@@ -21,7 +20,7 @@ pub struct DaemonWidthdraw<'info> {
     pub owner: Signer<'info>,
 }
 
-pub fn handler(ctx: Context<DaemonWidthdraw>, amount: u64) -> ProgramResult {
+pub fn handler(ctx: Context<DaemonWidthdraw>, amount: u64) -> Result<()> {
     let daemon = &mut ctx.accounts.daemon;
     let owner = &ctx.accounts.owner;
 
