@@ -10,7 +10,7 @@ pub mod daemon_create;
 pub mod daemon_invoke;
 pub mod daemon_widthdraw;
 pub mod fee_collect;
-pub mod health_check;
+pub mod health_ping;
 pub mod task_cancel;
 pub mod task_create;
 pub mod task_execute;
@@ -27,7 +27,7 @@ pub use daemon_create::*;
 pub use daemon_invoke::*;
 pub use daemon_widthdraw::*;
 pub use fee_collect::*;
-pub use health_check::*;
+pub use health_ping::*;
 pub use task_cancel::*;
 pub use task_create::*;
 pub use task_execute::*;
