@@ -4,7 +4,9 @@ pub mod state;
 
 mod instructions;
 
-use {anchor_lang::prelude::*, instructions::*, state::*};
+use anchor_lang::prelude::*;
+use instructions::*;
+use state::*;
 
 declare_id!("CronpZj5NbHj2Nb6WwEtf6A9anty9JfEQ1RnGoshQBaW");
 
@@ -12,7 +14,7 @@ declare_id!("CronpZj5NbHj2Nb6WwEtf6A9anty9JfEQ1RnGoshQBaW");
 pub mod cronos {
     use super::*;
 
-    pub fn admin_cancel_task(ctx: Context<AdminCancelTask>) -> ProgramResult {
+    pub fn admin_cancel_task(ctx: Context<AdminCancelTask>) -> Result<()> {
         admin_cancel_task::handler(ctx)
     }
 
@@ -21,7 +23,7 @@ pub mod cronos {
         ix: InstructionData,
         schedule: TaskSchedule,
         bump: u8,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         admin_create_task::handler(ctx, ix, schedule, bump)
     }
 
@@ -33,7 +35,7 @@ pub mod cronos {
         fee_bump: u8,
         health_bump: u8,
         treasury_bump: u8,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         admin_initialize::handler(
             ctx,
             authority_bump,
@@ -45,63 +47,59 @@ pub mod cronos {
         )
     }
 
-    pub fn admin_reset_health(ctx: Context<AdminResetHealth>) -> ProgramResult {
+    pub fn admin_reset_health(ctx: Context<AdminResetHealth>) -> Result<()> {
         admin_reset_health::handler(ctx)
     }
 
-    pub fn admin_update_admin(ctx: Context<AdminUpdateAdmin>, new_admin: Pubkey) -> ProgramResult {
+    pub fn admin_update_admin(ctx: Context<AdminUpdateAdmin>, new_admin: Pubkey) -> Result<()> {
         admin_update_admin::handler(ctx, new_admin)
     }
 
     pub fn admin_update_min_recurr(
         ctx: Context<AdminUpdateMinRecurr>,
         new_min_recurr: i64,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         admin_update_min_recurr::handler(ctx, new_min_recurr)
     }
 
     pub fn admin_update_program_fee(
         ctx: Context<AdminUpdateProgramFee>,
         new_program_fee: u64,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         admin_update_program_fee::handler(ctx, new_program_fee)
     }
 
     pub fn admin_update_worker_fee(
         ctx: Context<AdminUpdateWorkerFee>,
         new_worker_fee: u64,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         admin_update_worker_fee::handler(ctx, new_worker_fee)
     }
 
-    pub fn daemon_create(
-        ctx: Context<DaemonCreate>,
-        daemon_bump: u8,
-        fee_bump: u8,
-    ) -> ProgramResult {
+    pub fn daemon_create(ctx: Context<DaemonCreate>, daemon_bump: u8, fee_bump: u8) -> Result<()> {
         daemon_create::handler(ctx, daemon_bump, fee_bump)
     }
 
     pub fn daemon_invoke(
         ctx: Context<DaemonInvoke>,
         instruction_data: InstructionData,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         daemon_invoke::handler(ctx, instruction_data)
     }
 
-    pub fn daemon_widthdraw(ctx: Context<DaemonWidthdraw>, amount: u64) -> ProgramResult {
+    pub fn daemon_widthdraw(ctx: Context<DaemonWidthdraw>, amount: u64) -> Result<()> {
         daemon_widthdraw::handler(ctx, amount)
     }
 
-    pub fn fee_collect(ctx: Context<FeeCollect>) -> ProgramResult {
+    pub fn fee_collect(ctx: Context<FeeCollect>) -> Result<()> {
         fee_collect::handler(ctx)
     }
 
-    pub fn health_ping(ctx: Context<HealthPing>) -> ProgramResult {
+    pub fn health_ping(ctx: Context<HealthPing>) -> Result<()> {
         health_ping::handler(ctx)
     }
 
-    pub fn task_cancel(ctx: Context<TaskCancel>) -> ProgramResult {
+    pub fn task_cancel(ctx: Context<TaskCancel>) -> Result<()> {
         task_cancel::handler(ctx)
     }
 
@@ -110,11 +108,11 @@ pub mod cronos {
         ix: InstructionData,
         schedule: TaskSchedule,
         bump: u8,
-    ) -> ProgramResult {
+    ) -> Result<()> {
         task_create::handler(ctx, ix, schedule, bump)
     }
 
-    pub fn task_execute(ctx: Context<TaskExecute>) -> ProgramResult {
+    pub fn task_execute(ctx: Context<TaskExecute>) -> Result<()> {
         task_execute::handler(ctx)
     }
 }
